@@ -7,7 +7,7 @@ use Hash::Util qw(lock_keys);
 use Carp qw(confess);
 use Cwd;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =pod
 
@@ -50,7 +50,8 @@ sub new {
             unused       => 'Unused',
             same         => 'Same',
             non_jenkins  => 'Non Jenkins',
-            search_found => 'Found match on given term'
+            search_found => 'Found match on given term',
+            ignored      => 'Ignored due expected value'
         }
     };
 
